import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormControl, FormGroup, Validators } from '@angular/forms';
import { AuthService } from '../../services/auth.service';
import { ToastrService } from 'ngx-toastr';
import { Router } from '@angular/router';

@Component({
  selector: 'app-login',
  standalone: false,
  templateUrl: './login.component.html',
  styleUrls: ['../auth.module.scss', './login.component.scss']
})
export class LoginComponent implements OnInit {
  public loginForm!: FormGroup;

  constructor(
    private authService: AuthService,
    private formBuilder: FormBuilder,
    private toastrService: ToastrService,
    private router: Router
  ) { }

  ngOnInit(): void {
    this.loginForm = this.formBuilder.group({
      username: new FormControl('', [Validators.required]),
      password: new FormControl('', [Validators.required])
    })
  }

  login(): void {
    if (this.loginForm.valid) {
      this.authService.Login(
        this.loginForm.get('username')!.value,
        this.loginForm.get('password')!.value
      ).subscribe({
        next: result => {
          if (result.error) {
            this.toastrService.error(result.error, "Error");
          } else {
            this.toastrService.info(result.message, "Success");
            this.router.navigateByUrl('chat');
          }
        },
        error: () => {
          this.toastrService.error("API error", "Error");
        }
      })
    }
  }
}
