import { Component } from '@angular/core';
import { AuthService } from '../../services/auth.service';
import { FormBuilder, FormControl, FormGroup, Validators } from '@angular/forms';
import { ToastrService } from 'ngx-toastr';
import { Router } from '@angular/router';

@Component({
  selector: 'app-register',
  standalone: false,
  templateUrl: './register.component.html',
  styleUrls: ['../auth.module.scss', './register.component.scss']
})
export class RegisterComponent {
  registerForm!: FormGroup;

  constructor(
    private authService: AuthService,
    private formBuilder: FormBuilder,
    private toastrService: ToastrService,
    private router: Router
  ) { }

  ngOnInit(): void {
    this.registerForm = this.formBuilder.group({
      username: new FormControl('', [
        Validators.required,
        Validators.minLength(3),
        Validators.maxLength(32)
      ]),
      password: new FormControl('', [
        Validators.required,
        Validators.minLength(6),
        Validators.maxLength(32)
      ]),
      repeatPassword: new FormControl('', [
        Validators.required,
        Validators.minLength(6),
        Validators.maxLength(32),
      ])
    })
  }

  register(): void {
    if (this.registerForm.valid) {
      this.authService.Register(
        this.registerForm.get('username')!.value,
        this.registerForm.get('password')!.value,
        this.registerForm.get('repeatPassword')!.value
      ).subscribe({
        next: result => {
          if (result.error) {
            this.toastrService.error(result.error, "Error");
          } else {
            this.toastrService.info(result.message, "Success");
            this.router.navigateByUrl('/auth/login');
          }
        },
        error: _ => {
          this.toastrService.error("API error", "Error");
        }
      })
    }
  }
}
