import { Component, OnInit, ViewChild } from '@angular/core';
import { Channel } from '../../models/channel';
import { Message } from '../../models/message';
import { ChatService } from '../../services/chat.service';
import { ToastrService } from 'ngx-toastr';
import { FeedComponent } from './feed/feed.component';
import { ChannelListComponent } from './channel-list/channel-list.component';
import { MatDrawer } from '@angular/material/sidenav';

@Component({
  selector: 'app-chat',
  standalone: false,
  templateUrl: './chat.component.html',
  styleUrl: './chat.component.scss'
})
export class ChatComponent implements OnInit {
  public selectedChannel: number = 0;
  public channels: { channel: Channel, messages: Message[] }[] = [];

  @ViewChild("drawer") drawer!: MatDrawer;
  @ViewChild("feed") feed!: FeedComponent;
  @ViewChild("channelList") channelList!: ChannelListComponent;

  constructor(private chatService: ChatService, private toastrService: ToastrService) { }

  ngOnInit(): void {
    this.getChannels();
  }

  private getChannels(): void {
    this.chatService.ListAvailableChannels().subscribe({
      next: channels => {
        this.channels = channels.map(channel => { return { channel: channel, messages: [] as Message[] } });
        this.getMessages();
      },
      error: _ => {
        this.toastrService.error("Failed to fetch channels.", "Error");
      }
    })
  }

  private getMessages(): void {
    this.channels.forEach((channelObj, i) => {
      this.chatService.GetMessages(channelObj.channel.id).subscribe({
        next: messages => {
          channelObj.messages.push(messages);
          this.feed.ScrollEventHandler();
          this.channelList.Notify(channelObj.channel.id);
        },
        error: _ => {
          this.toastrService.error(`Failed to fetch messages for channel ${channelObj.channel.name}.`, "Error");
        }
      });
    });
  }

  public GetChannelList(): Channel[] {
    return this.channels.map(c => c.channel);
  }

  public Select(channel: number): void {
    this.selectedChannel = channel;
    this.feed.ScrollEventHandler();
    this.drawer.close();
  }
}
