import { Component, Input, OnDestroy, OnInit } from '@angular/core';
import { UserService } from '../../../../../services/user.service';
import { ToastrService } from 'ngx-toastr';
import { Subject, takeUntil } from 'rxjs';

@Component({
  selector: 'app-profile-picture',
  standalone: false,
  templateUrl: './profile-picture.component.html',
  styleUrl: './profile-picture.component.scss'
})
export class ProfilePictureComponent implements OnInit, OnDestroy {
  @Input("username") public username!: string;
  public url?: string;

  private destroy: Subject<void> = new Subject<void>();

  constructor(private userService: UserService, private toastrService: ToastrService) { }

  ngOnInit(): void {
    this.userService.GetProfilePictureURL(this.username)
      .pipe(takeUntil(this.destroy))
      .subscribe({
        next: url => this.url = url,
        error: _ => {
          this.toastrService.error("failed to fetch user info", "Error")
        }
      });
  }

  ngOnDestroy(): void {
    this.destroy.next();
    this.destroy.complete();
  }
}
