import { Component, Input, OnInit } from '@angular/core';
import { ChatService } from '../../../services/chat.service';
import { FormBuilder, FormControl, FormGroup, Validators } from '@angular/forms';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-message-bar',
  standalone: false,
  templateUrl: './message-bar.component.html',
  styleUrl: './message-bar.component.scss'
})
export class MessageBarComponent implements OnInit {
  private readonly MAX_MESSAGE_LENGTH: number = 120;

  @Input('channel') channel!: number;

  public messageForm!: FormGroup;

  constructor(private chatService: ChatService,
    private formBuilder: FormBuilder,
    private toastrService: ToastrService) { }

  ngOnInit(): void {
    this.messageForm = this.formBuilder.group({
      content: new FormControl('', [
        Validators.required,
        Validators.minLength(1),
        Validators.maxLength(this.MAX_MESSAGE_LENGTH)
      ])
    });
  }

  public Send(): void {
    if (this.messageForm.valid) {
      this.chatService.SendMessage(
        this.channel,
        this.messageForm.get("content")!.value).subscribe(
          {
            next: () => this.messageForm.setValue({ "content": "" }),
            error: () => this.toastrService.error("Failed to send message.", "Error")
          });
    }
  }
}
