import { Component, EventEmitter, Input, Output } from '@angular/core';
import { MatToolbarModule } from '@angular/material/toolbar';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';
import { AuthService } from '../../services/auth.service';
import { ToastrService } from 'ngx-toastr';
import { Router } from '@angular/router';
import { NgIf } from '@angular/common';

@Component({
  selector: 'app-toolbar',
  imports: [MatToolbarModule, MatIconModule, MatButtonModule, NgIf],
  templateUrl: './toolbar.component.html',
  styleUrl: './toolbar.component.scss'
})
export class ToolbarComponent {
  @Output('sidebar') sidebar: EventEmitter<void> = new EventEmitter<void>();

  constructor(
    public authService: AuthService,
    private toastrService: ToastrService,
    private router: Router) { }

  public Logout(): void {
    this.authService.Logout()
      .subscribe({
        next: result => {
          if (result) {
            this.router.navigateByUrl('auth/login');
            this.toastrService.info("Successfully logged out", "Logout");
          } else {
            this.toastrService.error("Logout failed", "Error");
          }
        }
      });
  }
}
