import { Injectable } from '@angular/core';
import { catchError, map, Observable, shareReplay, tap, throwError } from 'rxjs';
import { User } from '../models/user';
import { HttpClient } from '@angular/common/http';
import { UserInfoResponse } from './responses/user';
import { environment } from '../../environment/environment';

@Injectable({
  providedIn: 'root'
})
export class UserService {
  private users: Map<string, Observable<User>> = new Map<string, Observable<User>>();

  constructor(private http: HttpClient) { }

  public GetUser(username: string): Observable<User> {
    let user = this.users.get(username);
    if (user) {
      return user;
    } else {
      let url = `${environment.apiBase}/user/info/${username}`
      let observable = this.http.get<UserInfoResponse>(url, { withCredentials: true })
        .pipe(
          map(response => {
            if (response.error) {
              throw new Error(response.error);
            }

            if (response.user) {
              return response.user;
            }

            throw new Error("bad API response, missing user with no error");
          }),
          catchError(error => throwError(() => new Error(error.error.message))),
          shareReplay({ bufferSize: 1, refCount: true })
        );
      this.users.set(username, observable);
      return observable;
    }
  }

  public GetProfilePictureURL(username: string): Observable<string> {
    return this.GetUser(username).pipe(map(user => user.picture));
  }
}
