import { Component, OnDestroy, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { User } from '../../models/user';
import { UserService } from '../../services/user.service';
import { ToastrService } from 'ngx-toastr';
import { Subscription } from 'rxjs';
import { AuthService } from '../../services/auth.service';
import { FormBuilder, FormControl, FormGroup, Validators } from '@angular/forms';

@Component({
  selector: 'app-user',
  standalone: false,
  templateUrl: './user.component.html',
  styleUrl: './user.component.scss'
})
export class UserComponent implements OnInit, OnDestroy {
  public username!: string;
  public user?: User;

  private sub?: Subscription;

  public passwordForm!: FormGroup;
  public statusForm!: FormGroup;
  public bioForm!: FormGroup;

  constructor(
    private route: ActivatedRoute,
    private userService: UserService,
    public authService: AuthService,
    private toastrService: ToastrService,
    private formBuilder: FormBuilder) {
    this.route.paramMap.subscribe(params => {
      this.username = params.get('username')!;
    });
  }

  ngOnInit(): void {
    this.passwordForm = this.formBuilder.group({
      newPassword: new FormControl('', [
        Validators.required,
        Validators.minLength(6),
        Validators.maxLength(32)
      ]),
      repeatNewPassword: new FormControl('', [
        Validators.required,
        Validators.minLength(6),
        Validators.maxLength(32)
      ]),
      password: new FormControl('', [
        Validators.required
      ])
    });

    this.statusForm = this.formBuilder.group({
      status: new FormControl('', [
        Validators.required,
        Validators.minLength(0),
        Validators.maxLength(200)
      ]),
    });

    this.bioForm = this.formBuilder.group({
      bio: new FormControl('', [
        Validators.required,
        Validators.minLength(0),
        Validators.maxLength(300)
      ]),
    });

    this.sub = this.userService.GetUser(this.username)
      .subscribe({
        next: user => {
          this.user = user;
          this.statusForm.setValue({ "status": user.status });
          this.bioForm.setValue({ "bio": user.bio });
        },
        error: () => this.toastrService.error("Failed to fectch user info.", "Error"),
      });
  }

  ngOnDestroy(): void {
    this.sub?.unsubscribe();
  }

  public ChangePassword(): void { }
  public ChangeStatus(): void { }
  public ChangeBio(): void { }
}
